import request from '@/utils/request'

// 查询车辆故障列表
export function listFaultInfo(query) {
  return request({
    url: '/enterprise/faultInfo/list',
    method: 'get',
    params: query
  })
}

// 查询车辆故障详细
export function getFaultInfo(id) {
  return request({
    url: '/enterprise/faultInfo/getInfo/' + id,
    method: 'get'
  })
}

// 新增车辆故障
export function addFaultInfo(data) {
  return request({
    url: '/enterprise/faultInfo/add',
    method: 'post',
    data: data
  })
}

// 修改车辆故障
export function updateFaultInfo(data) {
  return request({
    url: '/enterprise/faultInfo/edit',
    method: 'put',
    data: data
  })
}

// 删除车辆故障
export function delFaultInfo(id) {
  return request({
    url: '/enterprise/faultInfo/remove/' + id,
    method: 'delete'
  })
}

// 查询车辆故障列表
export function faultMessageList(query) {
  return request({
    url: '/enterprise/message/faultMessageList',
    method: 'get',
    params: query
  })
}

// 查询车辆故障类型
export function faultTypeDown(query) {
  return request({
    url: '/enterprise/type/faultTypeList',
    method: 'get',
    params: query
  })
}

